function [noiseviol] = suspViol(f,ifopar)
%Computation of the viol modes thermal noise of the mirror suspension. P.
%Puppo
ifo=ifopar;

% General parameter 
g=ifo.Constants.g; 
kb=ifo.Constants.kB;
Temp=ifo.Suspension.Temp

% Horizontal to Vertical coupling
thetaHV=ifo.Suspension.VHCoupling.theta;
%-------------Physical parameters----------------------------------
Tmirror=ifo.Constants.Temp1;
g=ifo.Constants.g;    %gravitational acceleration (m/s^2)
kb=ifo.Constants.kB;  %Boltzmann constant (J/K)
w=2*pi*f;
Lharm=ifo.Infrastructure.Length;
%-------------Mirror-----------------------------------------------
Mmirror=ifo.Suspension.Stage(1).Mass;   %Mirror mass
nw=ifo.Suspension.Stage(1).NWires;
Lmirror=ifo.Suspension.Stage(1).Length;
dwmirror=ifo.Suspension.Stage(1).WireDiameter;

alphamir=ifo.Suspension.Stage(1).Alpha;% FS expansion coefficient [1/K]
betamir=ifo.Suspension.Stage(1).dlnEdT;% FS 1/E dE/dT [1/K]
Cmir=ifo.Suspension.Stage(1).C;% FS Thermal coefficient [J/(kg K)] 
Kmir=ifo.Suspension.Stage(1).K;% FS thermal conduction [W/(m K)]
Ymir=ifo.Suspension.Stage(1).Y;
rhomir=ifo.Suspension.Stage(1).Rho;
phimir=ifo.Suspension.Stage(1).Phi ; % FS bulk loss angle
ds=ifo.Suspension.Stage(1).Dissdepth;% Surface depth
Qvhmirror=ifo.Suspension.Stage(1).Qvh;
rwmirror=dwmirror/2;
I2mirror=pi/4*rwmirror^4;
Amirror=pi*rwmirror^2;
Lambda=Mmirror*g/nw;
omega2g=(g/Lmirror)^0.5;
k2v=nw*Amirror*Ymir/Lmirror;
omega02v=(k2v/Mmirror)^0.5;
thetaHV=ifo.Suspension.VHCoupling.theta;
GammaMir=Lambda;
w=2*pi*f;
nmodi=100;
ke=(Lambda/I2mirror/Ymir)^0.5;

phithT=zeros(1,length(f));
phiT=zeros(1,length(f));
phiP=zeros(1,length(f));
omegaviol=zeros(1,nmodi);
iviol=zeros(1,nmodi);
phiviol=zeros(1,nmodi);
Trasf=zeros(length(f),nmodi);
Somma=zeros(length(f),nmodi);
%Mirror Pendulum Loss Angle
TensMirror=Mmirror*g/nw;
DFmirror=(1/Lmirror)*(nw*Ymir*I2mirror/Mmirror/g)^0.5;    %Dilution factor
mu=4/rwmirror;
%phie=(muw*hbs*Sw/Vw)*phisurf;  %eccess losses
phie=mu*ds*phimir;
%Thermoelastic noise
Delta=(Ymir*Tmirror/rhomir/Cmir)*(alphamir-betamir*(Lambda/Amirror/Ymir))^2;
tau=((Cmir*(2*rwmirror)^2)/2.16/2/pi/Kmir)*rhomir;
phiST=phie+phimir;
for i=1:length(w),
    phithT(i)=Delta*w(i)*tau/(1+w(i)^2*tau^2); 
end
phiT=phithT+phiST;
phiP=DFmirror*phiT;

%%%Mode frequencies and losses
for n=1:nmodi,
omegaviol(n)=2*pi*(n/2/Lmirror)*(GammaMir/Amirror/rhomir)^0.5*(1+(2/Lmirror)*(Ymir*I2mirror/GammaMir)^0.5);
phitheT(n)=Delta*omegaviol(n)*tau/(1+omegaviol(n)^2*tau^2); 
phiTot(n)=phiST+phitheT(n);
phiviol(n)=(2*phiTot(n)/ke/Lmirror)*(1+((n*pi)^2/2/Lmirror/ke));   
end

viol1=omegaviol(1)/2/pi
viol2=omegaviol(2)/2/pi
viol3=omegaviol(3)/2/pi
phiviol1=phiviol(1)
phiviol2=phiviol(2)
phiviol3=phiviol(3)

Factor=4*4*kb*Tmirror*2*rhomir*rwmirror^2*Lmirror/pi/Mmirror^2;

for i=1:length(w),
    Somma(i)=0;
    for n=1:nmodi,
    Trasf(n,i)=(1/n^2)*(phiviol(n)*omegaviol(n)^2)/((omegaviol(n)^2-w(i)^2)^2+(omegaviol(n)^2*phiviol(n))^2);
    Somma(i)=Somma(i)+Trasf(n,i);
    end
    noise(i)=((2/Lharm)^2)*(Factor*Somma(i)/w(i));
end

noiseviol=noise;
end


